@@ -98,6 +98,9 @@ class InputData:
             elif label == "molecule-info`":
                 self.validate_molecule_info(content)
                 self.data[label] = content
+            elif label == "ising-model":
+                self.validate_ising_model(content)
+                self.data[label] = content
             else:
                 self.data[label] = content
         except (OverflowError, TypeError, ValueError):
@@ -110,14 +113,14 @@ class InputData:
             "ansatz-parameters",
             "ising-model",
             "lattice",
+            "lp-model",
             "molecule-info",
             "operator",
             "pub",
-            "qubo-model",
             "vectors-data",
         ]:
             raise Exception(
-                f"Input data of type {label} is not supported. Please choose one of the following options: 'ising-model', 'lattice', 'molecule-info', 'operator', 'pub', 'qubo-model', 'data-vectors'."
+                f"Input data of type {label} is not supported. Please choose one of the following options: 'ising-model', 'lattice', 'lp-model', 'molecule-info', 'operator', 'pub', 'data-vectors'."
             )
         if label != "pub" and label in data.keys():
             raise Exception(
@@ -150,6 +153,43 @@ class InputData:
                 "The 'masses' must be a list of floats, one for each nucleus in the molecule."
             )
 
+    def validate_ising_model(self, ising_model):
+        if not isinstance(ising_model, dict):
+            raise Exception("The 'ising_model' must be a dictionary.")
+
+        for key in ising_model.keys():
+            if key not in ["h", "J"]:
+                raise Exception(
+                    "The 'ising_model' dictionary can only contain the keys: 'h' and 'J'."
+                )
+
+        if "h" in ising_model:
+            if not isinstance(ising_model["h"], list):
+                raise Exception("The 'h' field must be a list of numeric values.")
+            if not all(isinstance(h, (int, float)) for h in ising_model["h"]):
+                raise Exception("Each element in 'h' must be an int or float.")
+
+        if "J" in ising_model:
+            if not isinstance(ising_model["J"], list):
+                raise Exception("The 'J' field must be a list of dictionaries.")
+            for interaction in ising_model["J"]:
+                if not isinstance(interaction, dict):
+                    raise Exception(
+                        "Each item in 'J' must be a dictionary with 'pair' and 'value' keys."
+                    )
+                if "pair" not in interaction or "value" not in interaction:
+                    raise Exception(
+                        "Each item in 'J' must contain 'pair' and 'value' keys."
+                    )
+                if (
+                    not isinstance(interaction["pair"], list)
+                    or len(interaction["pair"]) != 2
+                    or not all(isinstance(i, int) for i in interaction["pair"])
+                ):
+                    raise Exception("'pair' must be a list of two integers.")
+                if not isinstance(interaction["value"], (int, float)):
+                    raise Exception("'value' must be a numeric type (int or float).")
+
     def validate_and_serialize_pub(self, pub):
         shots = None
         paramaters = None
@@ -433,10 +473,8 @@ In case the service has been recently started please wait 5 minutes for it to be
         if not workflow_id:
             print("Please specify a workflow Id.")
             return
-        if shots is None:
-            shots = 1024
-        if not isinstance(shots, int):
-            print("The number of shots must be an integer.")
+        if shots is not None and not isinstance(shots, int):
+            print("The number of shots must be an integer or 'None'.")
             return
         if not self.is_valid_uuid(workflow_id):
             print("The specified workflow Id is not valid.")
@@ -457,7 +495,7 @@ In case the service has been recently started please wait 5 minutes for it to be
             job_data = {
                 "BackendName": backend,
                 "WorkflowId": workflow_id,
-                "Shots": shots,
+                "Shots": str(shots),
                 "Comments": comments,
                 "InputDataLabels": input_data_labels,
                 "InputDataItems": input_data_items,
